/**
 * Modal
 * Dependencies:
 * - @gorhom/bottom-sheet.
 *
 * Props:
 * - All `BottomSheetModalProps` props.
 * - `title` (string | undefined): Optional title for the modal header.
 *
 * Usage Example:
 * import { Modal, useModal } from '@gorhom/bottom-sheet';
 *
 * function DisplayModal() {
 *   const { ref, present, dismiss } = useModal();
 *
 *   return (
 *     <View>
 *       <Modal
 *         snapPoints={['60%']} // optional
 *         title="Modal Title"
 *         ref={ref}
 *       >
 *         Modal Content
 *       </Modal>
 *     </View>
 *   );
 * }
 *
 */
import * as React from 'react';
export declare const useModal: () => {
    ref: React.MutableRefObject<BottomSheetModal>;
    present: (data?: any) => void;
    dismiss: () => void;
};
export declare const Modal: React.ForwardRefExoticComponent<Omit<any, "ref"> & React.RefAttributes<any>>;
export declare const renderBackdrop: (props: BottomSheetBackdropProps) => React.JSX.Element;
//# sourceMappingURL=modal.d.ts.map